==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/syntax/clsgreylistgrid.php <==
<?
require_once "inc/syntax/clsstdgrid.php";

/********** Quarantine GRID  - XML source *************/
class cGreyListGrid extends cStdGrid
{
  //Flags - type of queue (Quarantime,Whitelist,Greylist)
	function cGreyListGrid($option,$name,$count = 0,$type = false,$owner = false,$value = false)
	{
		$this->Name = $name;
    $this->Item = new cStdItem(8,";SEP;SEP;SEP;SEP;SEP;SEP;");
    
    $this->type = intval($type);
    $this->owner = $owner;
    $this->value = $value;
		$this->count = intval($count);
	}

	/* Gets buffer from file */
	function getBuffer()
	{
		global $api;
		$query = ' ';
		if ($this->type!=2)
		  $query.= "WHERE ipAuthorized = '".$this->type."'";
		  
		if ($this->owner)
		  $query.= ($query==' '?'WHERE':'AND')." ipEmail LIKE '".$this->owner."%'";
		  
		if ($this->value)
		  $query.= ($query==' '?'WHERE':'AND')." ipAddress LIKE '".$this->value."%'";
	 
		$this->Buffer = $api->GLList('', $query, $this->count);
 	}  

   	
	/* Build grid from buffer */
	function loadFromBuffer()
	{
		  if ($this->Buffer){
			$ic=0;
			/* explode buffer to lines */
			$lines = explode(CRLF,$this->Buffer);

			//Parse lines
			for ($i=0;$i<count($lines);$i++){
				$item = array();
				if ($lines[$i]=="") continue; // skip blank lines
				if ($this->Item->Length==1) $item[0]= $lines[$i];
				else{
					$pom = $lines[$i];
					for ($j=0;$j<$this->Item->Length-1;$j++){
						$pom = explode($this->Item->Seps[$j],$pom,2);
						$item[$j] = $pom[0];
						$pom = $pom[1];
					}
					$item[$j] = str_replace(";","",$pom);
				}
				$items[$ic++] = $item;
			}
			$this->Data = $items;
		}

	}
  function Save()
  {	  
    $noSaveActions = array(0=>'ch_whitelist',
                           1=>'ch_blacklist',
                           2=>'ch_delete',
                           3=>'ch_deliver',
                           4=>'ch_refresh',
                           4=>'g_refresh',
                           4=>'g_delete',
                           5=>'g_authorize');
    //TODO : when merak will suport
    /*if(!(in_array($_REQUEST['gridaction'],$noSaveActions) || $this->type==2))
    {
     $api = createobject("api");
     
     if ($this->Data) foreach($this->Data as $ajtem){
        $list = $api->GList();
        if ($list=='') 
          $api->GLAdd($ajtem[0],$ajtem[1],$ajtem[2]);     
     }
    }*/
  }

	
  function getGridButtons($option,$type)
	{
	  global $alang,$_REQUEST,$formapi,$value;
		@$files = $option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"];
		@$dialog = $files["DIALOG"];
		@$file = $files["NAME"];
		@$comment = $files["COMMENT"];
		if ($option["BUTTONS"][0]["BUTTON"])
		foreach($option["BUTTONS"][0]["BUTTON"] as $bk => $bv)
		{
		  unset($item);
			@$item["type"]=$bv["ATTRIBUTES"]["TYPE"];
			@$item["label"]=$alang[$bv["ATTRIBUTES"]["LABEL"]];
			@$width = $option["ATTRIBUTES"]["WIDTH"];
			if (@!$width) $width=640;
			@$height = $option["ATTRIBUTES"]["HEIGHT"];
			if (@!$height) $height=480;
			$item["onclick"]='processdatagrid("'.$item["type"].'","'.$dialog.'","'.$this->Name.'","",'.$width.','.$height.',"",'.$this->count.');';
			switch ($item["type"]){
			  case 'removeall':
				case 'g_authorize':
				case 'g_delete':
				case 'g_refresh':
				
					if ($type=="datagrid")	$nr = 'document.getElementById("noreload").value=1;';
					else $nr = '';
					$item["onclick"]=$nr.'document.getElementById("gridval").value="'.$this->Name.'";document.getElementById("gridaction").value="'.$item["type"].'";document.forms[0].submit();';
				break;
				
		}
		   $items[]=$item;
		}
		return $items;
	}
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/syntax/clsgreylistgrid.php <==
<?
require_once "inc/syntax/clsstdgrid.php";

/********** Quarantine GRID  - XML source *************/
class cGreyListGrid extends cStdGrid
{
  //Flags - type of queue (Quarantime,Whitelist,Greylist)
	function cGreyListGrid($option,$name,$count = 0,$type = false,$owner = false,$value = false)
	{
		$this->Name = $name;
    $this->Item = new cStdItem(8,";SEP;SEP;SEP;SEP;SEP;SEP;");
    
    $this->type = intval($type);
    $this->owner = $owner;
    $this->value = $value;
		$this->count = intval($count);
		
		$this->noLink = true;
	}

	/* Gets buffer from file */
	function getBuffer()
	{
		global $api;
		$query = ' ';
		if ($this->type!=2)
		  $query.= "WHERE ipAuthorized = '".$this->type."'";
		  
	//	if ($this->owner)
	
	 if($_SESSION['ACCOUNT']=='DOMAINADMIN'){
    if(strpos($this->owner,"@")!==false){
      $owner = substr($this->owner,0,strpos($this->owner,"@"));        
    }

    $list = getdomainlist();

    $ownerquery = '(';
    foreach($list as $dom)
    {  
     $ownerquery.= " ipEmail LIKE '".$owner."%".$dom['DOMAIN']."'";
     if ($count++ < count($list)-1) $ownerquery.= " OR ";
    }
    $ownerquery .= ')';
    $query.= "AND ".$ownerquery;
	}
		
    
		  
		if ($this->value)
		  $query.= ($query==' '?'WHERE':'AND')." ipAddress LIKE '".$this->value."%'";

		$this->Buffer = $api->GLList('', $query, $this->count);
		
 	}  

   	
	/* Build grid from buffer */
	function loadFromBuffer()
	{
		  if ($this->Buffer){
			$ic=0;
			/* explode buffer to lines */
			$lines = explode(CRLF,$this->Buffer);

			//Parse lines
			for ($i=0;$i<count($lines);$i++){
				$item = array();
				if ($lines[$i]=="") continue; // skip blank lines
				if ($this->Item->Length==1) $item[0]= $lines[$i];
				else{
					$pom = $lines[$i];
					for ($j=0;$j<$this->Item->Length-1;$j++){
						$pom = explode($this->Item->Seps[$j],$pom,2);
						if ($j==3)
						{
              $date = getDate(jdtounix($pom[0]));
              $hours = intval($pom[1]/3600).":";
              $time =  $hours.intval(($pom[1]-$hours*3600)/60);
              $pom[0] = $date['year'].'-'.$date['mon'].'-'.$date['mday'].' '.$time;
              
            }
						$item[$j] = $pom[0];
						$pom = $pom[1];

					}
					$item[$j] = str_replace(";","",$pom);
				}
				$items[$ic++] = $item;
			}
			$this->Data = $items;
		}
	} 
	
  function Save()
  {	  
    $noSaveActions = array(0=>'ch_whitelist',
                           1=>'ch_blacklist',
                           2=>'ch_delete',
                           3=>'ch_deliver',
                           4=>'ch_refresh',
                           4=>'g_refresh',
                           4=>'g_delete',
                           5=>'g_authorize');
    //TODO : when merak will suport
    /*if(!(in_array($_REQUEST['gridaction'],$noSaveActions) || $this->type==2))
    {
     $api = createobject("api");
     
     if ($this->Data) foreach($this->Data as $ajtem){
        $list = $api->GList();
        if ($list=='') 
          $api->GLAdd($ajtem[0],$ajtem[1],$ajtem[2]);     
     }
    }*/
  }

	
  function getGridButtons($option,$type)
	{
	  global $alang,$_REQUEST,$formapi,$value;
		@$files = $option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"];
		@$dialog = $files["DIALOG"];
		@$file = $files["NAME"];
		@$comment = $files["COMMENT"];
		if ($option["BUTTONS"][0]["BUTTON"])
		foreach($option["BUTTONS"][0]["BUTTON"] as $bk => $bv)
		{
		  unset($item);
			@$item["type"]=$bv["ATTRIBUTES"]["TYPE"];
			@$item["label"]=$alang[$bv["ATTRIBUTES"]["LABEL"]];
			@$width = $option["ATTRIBUTES"]["WIDTH"];
			if (@!$width) $width=640;
			@$height = $option["ATTRIBUTES"]["HEIGHT"];
			if (@!$height) $height=480;
			$item["onclick"]='processdatagrid("'.$item["type"].'","'.$dialog.'","'.$this->Name.'","",'.$width.','.$height.',"",'.$this->count.',0,\'\',\''.$this->uid.'\');';
			switch ($item["type"]){
			  case 'removeall':
				case 'g_authorize':
				case 'g_delete':
				case 'g_refresh':
				
					if ($type=="datagrid")	$nr = 'document.getElementById("noreload").value=1;';
					else $nr = '';
					$item["onclick"]=$nr.'document.getElementById("gridval").value="'.$this->Name.'";document.getElementById("gridaction").value="'.$item["type"].'";document.forms[0].submit();';
				break;
				
		}
		   $items[]=$item;
		}
		return $items;
	}
}
?>
